@@ -8,7 +8,8 @@ sudo apt-get install -y \
         debootstrap \
         inetutils-ping \
         kpartx \
-        qemu-utils || \
+        qemu-utils \
+        uuid-runtime || \
     sudo yum -y install \
         debootstrap \
         kpartx \
